@@ -12,10 +12,10 @@
 #' @param parms list of all parameters
 #' @return (scalar) limitation on growth (between 0 and 1)
 #' @export
-extraGrowthLimFuncDefault=function(strainName,groupName,pathName,stateVarValues,stateVarNames,time,parms){
-    #the output from this function will multiply maxGrowthRate
-    #it can therefore be used to inhibit growth in any way you like!
-    #the default is 1 (no limitation).
-    lim=1
-    return(min(max(lim,0),1))    #IMPORTANT! - output must be between 0 and 1
+extraGrowthLimFuncDefault = function(strainName, groupName, pathName, stateVarValues, 
+    stateVarNames, time, parms) {
+    # the output from this function will multiply maxGrowthRate it can therefore be
+    # used to inhibit growth in any way you like! the default is 1 (no limitation).
+    lim = 1
+    return(min(max(lim, 0), 1))  #IMPORTANT! - output must be between 0 and 1
 }
